@@ -15,21 +15,9 @@ def cli():
     """Kiraak CLI"""
 
 @cli.command()
-@click.argument(
-    "json_file", type=click.Path(exists=True, dir_okay=False)
-)
-def add(json_file: str) -> None:
+def add() -> None:
     """Add orders using the Kiraak API"""
-    try:
-        with open(json_file, "r") as file:
-            json.load(file)
-    except json.JSONDecodeError as err:
-        click.echo("File must be a valid JSON file!")
-        raise click.Abort() from err
-
-    click.echo(f"Adding orders from {json_file}")
-    main(json_file)
-
+    main()
 
 @cli.command()
 def clear() -> None:
