@@ -9,14 +9,7 @@ from kiraak import console
 from kiraak.api import get_catalog, login
 from kiraak.catalog import Catalog
 from kiraak.config import Auth
-
-wcapi = API(
-    url="https://rgbsocial.redgreenbluemix.com/",
-    consumer_key=Auth.WOOCOMMERCE_CONSUMER_KEY,
-    consumer_secret=Auth.WOOCOMMERCE_CONSUMER_SECRET,
-    wp_api=True,
-    version="wc/v3",
-)
+from kiraak import wc_api
 
 
 logger = logging.getLogger(__name__)
@@ -45,7 +38,7 @@ def compare():
 
     prods = []
     i = 1
-    while new_prods := wcapi.get("products", json={"page": i, "per_page": 20}).json():
+    while new_prods := wc_api.get("products", json={"page": i, "per_page": 20}).json():
         i += 1
         prods.extend(new_prods)
     print(prods)
