@@ -26,8 +26,7 @@ logging.captureWarnings(True)
 session = requests.Session()
 session.verify = False
 
-
-FLAT_RE = r"^(?P<block>[A-N])( |-)?(?P<flat>((0?[1-9]0|1[0-9]0|200|14A|14B)[1-4]))$"
+FLAT_RE = r"^(?P<block>[A-N])( |-)?(?P<flat>((0?[1-9]0|1[0-2]0|1[5-9]0|200|14A|14B)[1-4]))$"
 
 
 class Auth:
