@@ -1,7 +1,13 @@
+from datetime import datetime
 import logging
 import math
+from sqlite3 import Date
 import time
 from typing import Generator
+import os
+import json
+# import open
+
 
 from rich import print_json
 from woocommerce import API
@@ -10,15 +16,7 @@ from kiraak import console
 from kiraak.api import get_catalog, login
 from kiraak.catalog import Catalog
 from kiraak.config import Auth
-
-wcapi = API(
-    url="https://rgbsocial.redgreenbluemix.com/",
-    consumer_key=Auth.WOOCOMMERCE_CONSUMER_KEY,
-    consumer_secret=Auth.WOOCOMMERCE_CONSUMER_SECRET,
-    wp_api=True,
-    version="wc/v3",
-)
-
+from kiraak import wc_api
 
 logger = logging.getLogger(__name__)
 
@@ -73,7 +71,7 @@ def sync():
     logger.info("Fetching existing WooCommerce Products...")
     prods = []
     i = 1
-    while new_prods := wcapi.get("products", json={"page": i, "per_page": 100}).json():
+    while new_prods := wc_api.get("products", json={"page": i, "per_page": 100}).json():
         logger.info(f"Fetching page {i}")
         i += 1
         try:
@@ -83,34 +81,48 @@ def sync():
             pass
         prods.extend(new_prods)
 
-    logger.info(f"Recieved {len(prods)} existing WooCommerce Products")
+    logger.info(f"Received {len(prods)} existing WooCommerce Products")
     woocommerce_products = WC_Products(prods)
     woocommerce_products.update_prods(catalog)
     for prod in catalog:
         if not woocommerce_products.find_by_sku(prod.product_id):
             logger.warning(f"Product not found in WooCommerce: {prod.name} {prod.desc} {prod.quantity} ({prod.product_id})")
-    prods_to_update = [
+    
+    num_prods_status_changed = 0
+    num_prods_price_changed = 0
+    num_prods_name_changed = 0
+    prods_to_update = []
+    for x in woocommerce_products:
+        prods_to_update.append(
             {
                 "id": x.id,
                 "status": x.status,
                 "regular_price": x.price,
                 "name": x.name,
             }
-            for x in woocommerce_products
-            if (x.status != x.old_status or x.price != x.old_price or x.name != x.old_name)
-        ]
+        )
+        if (x.status != x.old_status):
+            num_prods_status_changed +=1
+        if (x.price != x.old_price):
+            num_prods_price_changed +=1 
+        if (x.name != x.old_name):
+            num_prods_name_changed += 1        
     logger.info(f"Syncing {len(prods_to_update)} products...")
-    for i in range(math.ceil(len(prods_to_update)/50)):
+    logger.info(f"changed status of {num_prods_status_changed} products in Woo Commerce")
+    logger.info(f"changed price of {num_prods_price_changed} products in Woo Commerce")
+    logger.info(f"changed name of {num_prods_name_changed} products in Woo Commerce")
+
+    for i in range(math.ceil(len(prods_to_update)/100)):
         logger.info(f"Syncing batch {i + 1}")
         data = {
-            "update": prods_to_update[i*50: (i + 1)*50]
+            "update": prods_to_update[i*100: (i + 1)*100]
         }
         for prod in woocommerce_products.updated_prods:
             logger.info(
-                f"Updating [bold]{prod.name}[/] ({prod.old_status!r} -> {prod.status!r}) (₹{prod.old_price!r} -> ₹{prod.old_price!r})",
+                f"Updating [bold]{prod.name}[/] ({prod.old_status!r} -> {prod.status!r}) (₹{prod.old_price!r} -> ₹{prod.price!r})",
                 extra={"markup": True}
             )
-        returned = wcapi.post("products/batch", data=data).json()
+        returned = wc_api.post("products/batch", data=data).json()
     logger.info("Synced!")
 
 def main(once, time_gap):
@@ -124,6 +136,7 @@ def main(once, time_gap):
     while not once:
         time.sleep(time_gap)
         sync()
-
+    
+    
 if __name__ == "__main__":
     main()
